#!/usr/bin/python -t
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import os
import sys
import rpmUtils
import shutil
import string

# get the path to where to look for the packages to be signed
# make repo
# make repoview
# email to fedora-extras-list with the built packages list
# sing, dance, romance

treedir = '/rpmbuild/extras/tree/extras'
cachedir = '/tmp/repomd-cache'
compsname = 'comps.xml'
archdict = {'3':['x86_64', 'i386'], 
            'development':['ppc','x86_64','i386'],
            '4':['ppc','x86_64', 'i386']}
ts = rpmUtils.transaction.initReadOnlyTransaction()


DEBUG = False

def debugprint(msg):
    if DEBUG:
        print msg
        

def main(dist):
    if not archdict.has_key(dist):
        print "No Distribution named %s found" % dist
        sys.exit(1)
        
    destdir = os.path.join(treedir, dist)

    print "Making Repository Metadata"
    # SRPM repo creation
    repodir = os.path.join(destdir, 'SRPMS')
    rpdata = os.path.join(repodir, 'repodata')
    debugprint('removing tree %s' % rpdata)
    if not DEBUG:
        if os.path.exists(rpdata): shutil.rmtree(rpdata)
        
    cmd = '/usr/bin/createrepo -c %s -q %s' % (cachedir, repodir)
    debugprint(cmd)
    if not DEBUG:    
        result = os.system(cmd)
        
    cmd = '/usr/bin/repoview %s' % repodir
    debugprint(cmd)
    if not DEBUG:    
        result = os.system(cmd)
    
    # arch repo creation
    for arch in archdict[dist]:
        repodir = os.path.join(destdir, arch)
        compspath = os.path.join(repodir, compsname)
        rpdata = os.path.join(repodir, 'repodata')
        debugprint('removing tree %s' % rpdata)
        if not DEBUG:        
            if os.path.exists(rpdata): shutil.rmtree(rpdata)
            
        if os.path.exists(compspath):
            cmd = '/usr/bin/createrepo -c %s -q -g %s -x *debuginfo* %s' % (cachedir, compsname, repodir)
        else:
            cmd = '/usr/bin/createrepo -c %s -q -x *debuginfo* %s' % (cachedir, repodir)
        debugprint(cmd)
        if not DEBUG:        
            result = os.system(cmd)
            
        cmd = '/usr/bin/repoview %s' % repodir
        debugprint(cmd)
        if not DEBUG:        
            result = os.system(cmd)
        
        dbg_repodir = os.path.join(destdir, arch, 'debug')
        dbg_rpdata = os.path.join(dbg_repodir, 'repodata')
        debugprint('removing tree %s' % dbg_rpdata)
        if not DEBUG:
            if os.path.exists(dbg_rpdata): shutil.rmtree(dbg_rpdata)
        
        cmd = '/usr/bin/createrepo -c %s -q %s' % (cachedir, dbg_repodir)
        debugprint(cmd)
        if not DEBUG:        
            result = os.system(cmd)
            
        cmd = '/usr/bin/repoview %s' % dbg_repodir
        debugprint(cmd)
        if not DEBUG:        
            result = os.system(cmd)
            
    
if __name__ == '__main__':
    me = os.getcwd()
    if len(sys.argv) < 2:
        print "Usage:\nextras-repobuild.py release\n\n"
        sys.exit(1)
    main(sys.argv[1])
    os.chdir(me)
    
